@@ -48,7 +48,7 @@ def main():
     )
     p.add("-c", "--config", is_config_file=True, help="config file path")
     p.add_argument("--log-level", "-L", default="DEBUG", env_var="LOG_LEVEL")
-    p.add_argument("--log-file", action="store_true", env_var="LOG_FILE")
+    p.add_argument("--log-file", type=str, default=True, env_var="LOG_FILE")
     args = p.parse_known_args()[0]
 
     logging.basicConfig(level=getattr(logging, args.log_level.upper()))
